
.. py:currentmodule:: pythreejs

CubeTexture
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: CubeTexture(images=[], mapping="UVMapping", wrapS="ClampToEdgeWrapping", wrapT="ClampToEdgeWrapping", magFilter="LinearFilter", minFilter="LinearMipMapLinearFilter", format="RGBAFormat", type="UnsignedByteType", anisotropy=1, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Texture`.

    Three.js docs: https://threejs.org/docs/#api/textures/CubeTexture


    .. py:attribute:: images

        .. sourcecode:: python

            List().tag(sync=True)

